# Sorcerun

Sorcerun is a command-line interface (CLI) designed to streamline the execution and management of computational experiments. It provides built-in support for MongoDB and Sacred, simplifying experiment setup and deployment. Users can configure experiments with a single adapter function, while Sorcerun handles running, logging, and authentication. Additionally, the CLI allows for easy management of MongoDB servers and integrates with the OmniBoard web dashboard for tracking and visualization. Sorcerun aims to facilitate a more efficient experiment lifecycle for researchers, data scientists, and engineers.

TODO: add simple example

# TODO

-   [ ] Utilities to forward ports via ssh
-   [ ] Grid run utilities via CLI
-   [ ] More template adapters and generate them via CLI
    -   Specifically something that can track STDOUT and log metrics from STDOUT?
-   [ ] Cleaner source file and other meta info tracking
-   [ ] General utilities with `incense` -- maybe build `streamlit` app separately?
-   [ ] Better logging for the mongod server
-   [ ] Add example and documentation
